==> replica-2.0.0-b5.tar.gz: lib/replica.dart <==
library replica;

import 'dart:io';

import 'package:replica/src/compiler.dart';
import 'package:replica/src/mirror_context.dart';

export 'src/analyzer.dart';
export 'src/context.dart';
export 'src/build.dart';
export 'src/compiler.dart';
export 'src/file_system.dart';
export 'src/generator.dart';
export 'src/build_context.dart';
export 'src/build_manager.dart';
export 'src/mirror_context.dart';
export 'src/exceptions.dart';
export 'src/mirror_coerce.dart';

/// Compiler for the replica package itself.
///
/// Removes dart:mirror from a replica of this package, and adds
/// a generated replica to the replica's pubspec.
class RuntimePackageCompiler extends Compiler {
  @override
  Map<String, dynamic> compile(MirrorContext context) => {};

  @override
  void deflectPackage(Directory destinationDirectory) {
    final libraryFile = File.fromUri(
        destinationDirectory.uri.resolve("lib/").resolve("replica.dart"));
    libraryFile
        .writeAsStringSync("library replica;\nexport 'src/context.dart';\nexport 'src/exceptions.dart';");

    final contextFile = File.fromUri(destinationDirectory.uri
        .resolve("lib/")
        .resolve("src/")
        .resolve("context.dart"));
    final contextFileContents = contextFile.readAsStringSync().replaceFirst(
        "import 'package:replica/src/mirror_context.dart' as context;",
        "import 'package:generated_replica/generated_replica.dart' as context;");
    contextFile.writeAsStringSync(contextFileContents);

    final pubspecFile = File.fromUri(destinationDirectory.uri.resolve("pubspec.yaml"));
    final pubspecContents = pubspecFile.readAsStringSync().replaceFirst("\ndependencies:",
      "\ndependencies:\n  generated_replica:\n    path: ../../generated_replica/");
    pubspecFile.writeAsStringSync(pubspecContents);
  }
}

==> replica-2.0.1.tar.gz: lib/replica.dart <==
library replica;

import 'dart:io';

import 'package:replica/src/compiler.dart';
import 'package:replica/src/mirror_context.dart';

export 'src/analyzer.dart';
export 'src/context.dart';
export 'src/build.dart';
export 'src/compiler.dart';
export 'src/file_system.dart';
export 'src/generator.dart';
export 'src/build_context.dart';
export 'src/build_manager.dart';
export 'src/mirror_context.dart';
export 'src/exceptions.dart';
export 'src/mirror_coerce.dart';

/// Compiler for the replica package itself.
///
/// Removes dart:mirror from a replica of this package, and adds
/// a generated replica to the replica's pubspec.
class RuntimePackageCompiler extends Compiler {
  @override
  Map<String, dynamic> compile(MirrorContext context) => {};

  @override
  void deflectPackage(Directory destinationDirectory) {
    final libraryFile = File.fromUri(
        destinationDirectory.uri.resolve("lib/").resolve("replica.dart"));
    libraryFile.writeAsStringSync(
        "library replica;\nexport 'src/context.dart';\nexport 'src/exceptions.dart';");

    final contextFile = File.fromUri(destinationDirectory.uri
        .resolve("lib/")
        .resolve("src/")
        .resolve("context.dart"));
    final contextFileContents = contextFile.readAsStringSync().replaceFirst(
        "import 'package:replica/src/mirror_context.dart' as context;",
        "import 'package:generated_replica/generated_replica.dart' as context;");
    contextFile.writeAsStringSync(contextFileContents);

    final pubspecFile =
        File.fromUri(destinationDirectory.uri.resolve("pubspec.yaml"));
    final pubspecContents = pubspecFile.readAsStringSync().replaceFirst(
        "\ndependencies:",
        "\ndependencies:\n  generated_replica:\n    path: ../../generated_replica/");
    pubspecFile.writeAsStringSync(pubspecContents);
  }
}
